@@ -2,14 +2,15 @@
 import socket
 import time
 import traceback
-from collections import namedtuple, deque
+from collections import deque
 from itertools import islice
 from struct import Struct
 from typing import Any, Iterable, Optional, Tuple, Iterator
 from urllib.parse import urlparse
-import logging
 
 from osef import types
+from osef._logger import osef_logger
+from osef.constants import _Tlv, _TreeNode, _STRUCT_FORMAT
 
 TCP_TIMEOUT = 3
 
@@ -52,7 +53,11 @@ class OsefStream:
             try:
                 msg = self._io_stream.recv(size)
             except socket.timeout:
-                logging.warning("Receive timeout. Closing socket.")
+                osef_logger.warning("Receive timeout. Closing socket.")
+                self._io_stream.close()
+                msg = None
+            except ConnectionResetError:
+                osef_logger.warning("Socket reset error. Closing socket.")
                 self._io_stream.close()
                 msg = None
             return msg
@@ -69,7 +74,6 @@ class OsefStream:
         retry = 0
 
         while True:
-            error_string = ""
             try:
                 tcp_socket.settimeout(TCP_TIMEOUT)
                 tcp_socket.connect(
@@ -83,21 +87,18 @@ class OsefStream:
             except OSError as os_error:
                 error_string = f"Error during connection: {os_error}."
             if retry % 100 == 0:
-                logging.error(error_string)
+                osef_logger.error(error_string)
 
             if not auto_reconnect:
                 break
             if retry % 100 == 0:
-                logging.warning("Retrying to connect ...")
+                osef_logger.warning("Retrying to connect ...")
             retry = retry + 1
             time.sleep(0.005)
 
         self._io_stream = tcp_socket
 
 
-_Tlv = namedtuple("TLV", "type length value")
-
-
 def iter_file(osef_stream: OsefStream, auto_reconnect: bool = True) -> Iterator[_Tlv]:
     """Iterator function to iterate over each frame in osef file.
 
@@ -110,13 +111,13 @@ def iter_file(osef_stream: OsefStream, auto_reconnect: bool = True) -> Iterator[
             frame_tlv = read_next_tlv(osef_stream)
         except EOFError:
             if auto_reconnect and osef_stream.is_tcp:
-                logging.warning("Connection lost: reopening socket")
+                osef_logger.warning("Connection lost: reopening socket")
                 osef_stream.open_socket(auto_reconnect)
                 continue
             break
         except Exception:  # pylint: disable=broad-except
-            logging.error(
-                "Error: cannot read next Tlv from file (malformated Tlv?).\n"
+            osef_logger.error(
+                "Error: cannot read next Tlv from file (malformed Tlv?).\n"
                 + f"Details: {traceback.format_exc()}"
                 + "\n"
             )
@@ -145,9 +146,6 @@ def get_tlv_iterator(
     return deque(islice(enumerate(iter_file(opened_file, auto_reconnect)), first), last)
 
 
-_TreeNode = namedtuple("TreeNode", "type children leaf_value")
-
-
 def build_tree(tlv: _Tlv) -> _TreeNode:
     """Recursive function to get a tree from a raw Tlv frame
 
@@ -180,8 +178,8 @@ def unpack_value(value: bytes, leaf_info: types.LeafInfo, type_name: str = "") -
     """
     try:
 
-        if leaf_info.parsing_function is not None:
-            return leaf_info.parsing_function(value)
+        if leaf_info.unpack_function is not None:
+            return leaf_info.unpack_function(value)
         # unknown parser
         return value
 
@@ -224,13 +222,6 @@ def parse(
 
 # -- Tlv Parsing --
 
-# Structure Format definition (see https://docs.python.org/3/library/struct.html#format-strings):
-# Meant to be used as: _STRUCT_FORMAT % length
-_STRUCT_FORMAT = "<"  # little endian
-_STRUCT_FORMAT += "L"  # unsigned long        (field 'T' ie. 'Type')
-_STRUCT_FORMAT += "L"  # unsigned long        (field 'L' ie. 'Length')
-_STRUCT_FORMAT += "%ds"  # buffer of fixed size (field 'V' ie. 'Value')
-
 
 def read_next_tlv(osef_stream: OsefStream) -> Optional[_Tlv]:
     """Read the next TLV from a binary stream (file or socket)"""
